diff --git a/sys/kern/subr_bus.c b/sys/kern/subr_bus.c
index 46c17b9..0e2bb99 100644
--- a/sys/kern/subr_bus.c
+++ b/sys/kern/subr_bus.c
@@ -2084,11 +2084,24 @@ resource_kenv(const char *name, int unit, const char *resname, long *result)
 	const char *env;
 	char buf[64];
 
+	/*
+	 * DragonFly style loader.conf hinting
+	 */
 	ksnprintf(buf, sizeof(buf), "%s%d.%s", name, unit, resname);
 	if ((env = kgetenv(buf)) != NULL) {
 		*result = strtol(env, NULL, 0);
 		return(0);
 	}
+
+	/*
+	 * Also support FreeBSD style loader.conf hinting
+	 */
+	ksnprintf(buf, sizeof(buf), "hint.%s.%d.%s", name, unit, resname);
+	if ((env = kgetenv(buf)) != NULL) {
+		*result = strtol(env, NULL, 0);
+		return(0);
+	}
+
 	return (ENOENT);
 }
 
@@ -2140,12 +2153,24 @@ resource_string_value(const char *name, int unit, const char *resname,
 	char buf[64];
 	const char *env;
 
+	/*
+	 * DragonFly style loader.conf hinting
+	 */
 	ksnprintf(buf, sizeof(buf), "%s%d.%s", name, unit, resname);
 	if ((env = kgetenv(buf)) != NULL) {
 		*result = env;
 		return 0;
 	}
 
+	/*
+	 * Also support FreeBSD style loader.conf hinting
+	 */
+	ksnprintf(buf, sizeof(buf), "hint.%s.%d.%s", name, unit, resname);
+	if ((env = kgetenv(buf)) != NULL) {
+		*result = env;
+		return 0;
+	}
+
 	if ((error = resource_find(name, unit, resname, &res)) != 0)
 		return(error);
 	if (res->type != RES_STRING)
